// Specify the URL of the CSV file
const csvUrl =
  'https://gist.githubusercontent.com/MSushmaReddy/66ceeafc6c9fbeafd3fa01bdfcd192af/raw/4b076ca7a350b514946c00e1d12b834d3acebf6f/CarsProduction.csv';

// Load data from the CSV file using D3
d3.csv(csvUrl)
  .then(function (data) {
    // Convert string values to numbers if needed
    data.forEach(function (d) {
      d.Year = +d.Year;
      d.Production = +d.Production;
    });

    // Set up dimensions for the chart
    const width = 800;
    const height = 400;
    const margin = {
      top: 20,
      right: 20,
      bottom: 50,
      left: 50,
    };
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;

    // Create SVG element
    const svg = d3
      .select('body')
      .append('svg')
      .attr('id', 'areachart')
      .attr('width', width)
      .attr('height', height);

    // Create scales
    const xScale = d3
      .scaleLinear()
      .domain(d3.extent(data, (d) => d.Year))
      .range([margin.left, innerWidth]);

    const yScale = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.Production)])
      .range([innerHeight, margin.top]);

    // Create area generator
    const area = d3
      .area()
      .x((d) => xScale(d.Year))
      .y0(innerHeight)
      .y1((d) => yScale(d.Production));

    // Append area to SVG with a different color
    svg
      .append('path')
      .datum(data)
      .attr('fill', 'lightgreen') // Change the color here
      .attr('d', area);

    // Create axes
    const xAxis = d3
      .axisBottom(xScale)
      .tickFormat(d3.format('d'));
    const yAxis = d3.axisLeft(yScale);

    // Append axes to SVG
    svg
      .append('g')
      .attr('transform', `translate(0, ${innerHeight})`)
      .call(xAxis)
      .append('text')
      .attr('x', innerWidth / 2)
      .attr('y', margin.bottom - 10)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .text('Year');

    svg
      .append('g')
      .attr('transform', `translate(${margin.left}, 0)`)
      .call(yAxis)
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('x', -innerHeight / 2)
      .attr('y', -margin.left + 15)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .text('Production');
  })
  .catch(function (error) {
    console.log('Error loading data: ', error);
  });
